@@ -7,7 +7,7 @@ of files.
 import collections
 
 from . import util
-from .compat import iterkeys, izip_longest, string_types
+from .compat import iterkeys, izip_longest, string_types, unicode
 
 
 class PathSpec(object):
@@ -70,6 +70,9 @@ class PathSpec(object):
 		if not callable(pattern_factory):
 			raise TypeError("pattern_factory:{0!r} is not callable.".format(pattern_factory))
 
+		if isinstance(lines, (bytes, unicode)):
+			raise TypeError("lines:{0!r} is not an iterable.".format(lines))
+
 		lines = [pattern_factory(line) for line in lines if line]
 		return cls(lines)
 
@@ -104,6 +107,9 @@ class PathSpec(object):
 		Returns the matched files (:class:`~collections.Iterable` of
 		:class:`str`).
 		"""
+		if isinstance(files, (bytes, unicode)):
+			raise TypeError("files:{0!r} is not an iterable.".format(files))
+
 		file_map = util.normalize_files(files, separators=separators)
 		matched_files = util.match_files(self.patterns, iterkeys(file_map))
 		for path in matched_files:
